@@ -205,7 +205,10 @@ public:
 
     result=Lum::Images::WriteJPEG(path.GetPath(),image,options);
 
-    if (!result) {
+    if (result) {
+      std::cout << "Stored image \"" << Lum::Base::WStringToString(path.GetPath()) << "\"" << std::endl;
+    }
+    else {
       Lum::Dlg::Msg::ShowOk(this,
                             L"Error while storing image!",
                             std::wstring(L"The was an error while storing the image with the filename\n")+
@@ -219,7 +222,7 @@ public:
   void PreInit()
   {
     Lum::LED           *led;
-    Lum::Panel         *vpanel,*vpanel2,*hpanel;
+    Lum::Panel         *vpanel,*hpanel;
 
     vpanel=Lum::VPanel::Create(true,true);
 
@@ -229,24 +232,19 @@ public:
 
     hpanel->Add(Lum::AspectRatio::Create(control,640,480,true,true));
     hpanel->AddSpace();
-
-    vpanel2=Lum::VPanel::Create(false,true);
+    hpanel->Add(Lum::Button::Create(L"_Klick!",knips,Lum::Button::typeDefault,false,true));
 
     led=new Lum::LED();
     led->SetModel(knipsing);
-    vpanel2->Add(led);
-
-    vpanel2->AddSpace();
-    vpanel2->Add(Lum::Button::Create(L"_Klick!",knips,Lum::Button::typeDefault,false,true));
-
-    hpanel->Add(vpanel2);
 
     vpanel->Add(hpanel);
     vpanel->AddSpace();
     vpanel->Add(Lum::HPanel::Create(true,false)
                 ->Add(new Lum::Text(L"Prefix:"))
                 ->AddSpace()
-                ->Add(Lum::String::Create(imagePrefix,true,false)));
+                ->Add(Lum::String::Create(imagePrefix,true,false))
+                ->AddSpace()
+                ->Add(led));
 
     SetMain(vpanel);
 
